@@ -14,13 +14,12 @@ from .utils.short import get_real_url
 from .utils.parse_link import ResourceType, parse_link
 from .utils.aid_bvid_transformer import aid2bvid, bvid2aid
 from .utils.danmaku import DmMode, Danmaku, DmFontSize, SpecialDanmaku
-from .utils.network_httpx import (
+from .utils.network import (
     HEADERS,
     Api,
     retry,
     enc_wbi,
     get_nav,
-    request,
     check_valid,
     get_session,
     set_session,
@@ -52,7 +51,6 @@ from . import (
     rank,
     user,
     vote,
-    album,
     audio,
     emoji,
     login,
@@ -83,7 +81,7 @@ from . import (
     interactive_video,
 )
 
-BILIBILI_API_VERSION = "15.5.3"
+BILIBILI_API_VERSION = "16.0.0"
 
 # 如果系统为 Windows，则修改默认策略，以解决代理报错问题
 if "windows" in platform.system().lower():
@@ -117,7 +115,6 @@ __all__ = [
     "SpecialDanmaku",
     "VideoUploadException",
     "aid2bvid",
-    "album",
     "app",
     "article",
     "article_category",
@@ -153,7 +150,6 @@ __all__ = [
     "parse_link",
     "platform",
     "rank",
-    "request",
     "retry",
     "search",
     "session",
