@@ -14,7 +14,7 @@ from .utils.srt2ass import srt2ass
 from .utils.json2srt import json2srt
 from .utils.credential import Credential
 from .utils.danmaku2ass import Danmaku2ASS
-from .utils.network_httpx import get_session
+from .utils.network import get_session
 from .exceptions.ArgsException import ArgsException
 
 
@@ -154,9 +154,7 @@ async def make_ass_file_danmakus_protobuf(
     static_time=5,
 ) -> None:
     """
-    生成视频弹幕文件 *★,°*:.☆(￣▽￣)/$:*.°★* 。
-
-    强烈推荐 PotPlayer, 电影与电视全部都是静态的，不能滚动。
+    生成视频弹幕文件
 
     来源：protobuf
 
@@ -245,9 +243,7 @@ async def make_ass_file_danmakus_xml(
     static_time=5,
 ) -> None:
     """
-    生成视频弹幕文件 *★,°*:.☆(￣▽￣)/$:*.°★* 。
-
-    强烈推荐 PotPlayer, 电影与电视全部都是静态的，不能滚动。
+    生成视频弹幕文件
 
     来源：xml
 
