@@ -23,9 +23,12 @@ from .video import Video
 from .utils.utils import get_api
 from .utils.credential import Credential
 from .exceptions.ApiException import ApiException
-from .utils.network_httpx import request, Api, get_session
-from .exceptions.ResponseException import ResponseException
-from .utils.initial_state import get_initial_state, get_initial_state_sync
+from .utils.network import Api, get_session
+from .utils.initial_state import (
+    get_initial_state,
+    get_initial_state_sync,
+    InitialDataType,
+)
 
 API = get_api("bangumi")
 
@@ -1008,8 +1011,10 @@ class Bangumi:
                 url=api["url"], params=params, cookies=self.credential.get_cookies()
             )
             meta.raise_for_status()
-            # print(meta.json())
-            self.__ssid = meta.json()["result"]["media"]["season_id"]
+            if meta.json()["code"] == 0:
+                self.__ssid = meta.json()["result"]["media"]["season_id"]
+            else:
+                raise ApiException(msg=meta.json()["message"])
             params["media_id"] = media_id
         # 处理正常情况
         if self.__ssid != -1:
@@ -1165,7 +1170,9 @@ class Bangumi:
             )
             api = API["info"]["episodes_list"]
             params = {"season_id": self.__ssid}
-            return await Api(**api, credential=credential).update_params(**params).result
+            return (
+                await Api(**api, credential=credential).update_params(**params).result
+            )
 
     async def get_episodes(self) -> List["Episode"]:
         """
@@ -1177,10 +1184,12 @@ class Bangumi:
             return []
         first_epid = episode_list["main_section"]["episodes"][0]["id"]
         credential = self.credential if self.credential else Credential()
-        bangumi_meta = await get_initial_state(
-            url=f"https://www.bilibili.com/bangumi/play/ep{first_epid}",
-            credential=credential,
-        )
+        content_type = None
+        while content_type != InitialDataType.NEXT_DATA:
+            bangumi_meta, content_type = await get_initial_state(
+                url=f"https://www.bilibili.com/bangumi/play/ep{first_epid}",
+                credential=credential,
+            )
         bangumi_meta["media_id"] = self.get_media_id()
 
         episodes = []
@@ -1288,22 +1297,48 @@ class Episode(Video):
             credential (Credential, optional): 凭据. Defaults to None.
         """
         global episode_data_cache
-        self.credential = credential if credential else Credential()
-        self.__epid = epid
+        self.credential: Credential = credential if credential else Credential()
+        self.__epid: int = epid
 
         if not epid in episode_data_cache.keys():
-            content = get_initial_state_sync(
+            res, content_type = get_initial_state_sync(
                 url=f"https://www.bilibili.com/bangumi/play/ep{self.__epid}",
                 credential=self.credential,
-            )
+            )  # 随机 __NEXT_DATA__ 见 https://github.com/Nemo2011/bilibili-api/issues/433
+            if content_type == InitialDataType.NEXT_DATA:
+                content = res["props"]["pageProps"]["dehydratedState"]["queries"][0][
+                    "state"
+                ]["data"]["mediaInfo"]
+                self.bangumi = (
+                    Bangumi(ssid=content["season_id"])
+                    if not epid in episode_data_cache.keys()
+                    else episode_data_cache[epid]["bangumi_class"]
+                )
+                for ep_info in content["episodes"]:
+                    if int(
+                        ep_info["id"] if "id" in ep_info else ep_info["ep_id"]
+                    ) == int(epid):
+                        bvid = ep_info["bvid"]
+                        self.__ep_info: dict = ep_info
+                        break
+            else:  # InitialDataType.INITIAL_STATE
+                self.__ep_info: dict = res["epInfo"]
+                self.bangumi = (
+                    Bangumi(ssid=res["mediaInfo"]["season_id"])
+                    if not epid in episode_data_cache.keys()
+                    else episode_data_cache[epid]["bangumi_class"]
+                )
+                bvid = res["epInfo"]["bvid"]
         else:
             content = episode_data_cache[epid]["bangumi_meta"]
-
-        bvid = content["epInfo"]["bvid"]
-        if not epid in episode_data_cache.keys():
-            self.bangumi = Bangumi(ssid=content["mediaInfo"]["season_id"])
-        else:
+            bvid = None
+            for einfo in content["props"]["pageProps"]["dehydratedState"]["queries"][0][
+                "state"
+            ]["data"]["mediaInfo"]["episodes"]:
+                if einfo["ep_id"] == epid:
+                    bvid = einfo["bvid"]
             self.bangumi = episode_data_cache[epid]["bangumi_class"]
+            self.__ep_info: dict = episode_data_cache[epid]
 
         self.video_class = Video(bvid=bvid, credential=self.credential)
         super().__init__(bvid=bvid, credential=self.credential)
@@ -1350,10 +1385,24 @@ class Episode(Video):
         Returns:
             HTML 中的数据
         """
-        return await get_initial_state(
-            url=f"https://www.bilibili.com/bangumi/play/ep{self.__epid}",
-            credential=self.credential,
-        )
+        if self.__ep_info is None:
+            res, content_type = get_initial_state(
+                url=f"https://www.bilibili.com/bangumi/play/ep{self.__epid}",
+                credential=self.credential,
+            )
+            if content_type == InitialDataType.NEXT_DATA:
+                content = res["props"]["pageProps"]["dehydratedState"]["queries"][0][
+                    "state"
+                ]["data"]["mediaInfo"]
+                for ep_info in content["episodes"]:
+                    if int(
+                        ep_info["id"] if "id" in ep_info else ep_info["ep_id"]
+                    ) == int(self.get_epid()):
+                        return ep_info
+            else:
+                return res["epInfo"]
+        else:
+            return self.__ep_info
 
     async def get_bangumi_from_episode(self) -> "Bangumi":
         """
@@ -1383,7 +1432,9 @@ class Episode(Video):
                 "fnval": 4048,
                 "fourk": 1,
             }
-        return await Api(**api, credential=self.credential).update_params(**params).result
+        return (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
 
     async def get_danmaku_xml(self) -> str:
         """
