@@ -17,7 +17,7 @@ from typing import Union
 
 from .utils.utils import get_api
 from .utils.credential import Credential
-from .utils.network_httpx import Api
+from .utils.network import Api
 from .exceptions.ArgsException import ArgsException
 
 API = get_api("common")
@@ -132,7 +132,11 @@ class Comment:
         self.credential.raise_for_no_bili_jct()
 
         api = API["comment"]["like"]
-        return await Api(**api, credential=self.credential).update_data(**self.__get_data(status)).result
+        return (
+            await Api(**api, credential=self.credential)
+            .update_data(**self.__get_data(status))
+            .result
+        )
 
     async def hate(self, status: bool = True) -> dict:
         """
@@ -149,7 +153,11 @@ class Comment:
         self.credential.raise_for_no_bili_jct()
 
         api = API["comment"]["hate"]
-        return await Api(**api, credential=self.credential).update_data(**self.__get_data(status)).result
+        return (
+            await Api(**api, credential=self.credential)
+            .update_data(**self.__get_data(status))
+            .result
+        )
 
     async def pin(self, status: bool = True) -> dict:
         """
@@ -165,7 +173,11 @@ class Comment:
         self.credential.raise_for_no_bili_jct()
 
         api = API["comment"]["pin"]
-        return await Api(**api, credential=self.credential).update_data(**self.__get_data(status)).result
+        return (
+            await Api(**api, credential=self.credential)
+            .update_data(**self.__get_data(status))
+            .result
+        )
 
     async def delete(self) -> dict:
         """
@@ -204,7 +216,9 @@ class Comment:
             "root": self.__rpid,
         }
 
-        return await Api(**api, credential=self.credential).update_params(**params).result
+        return (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
 
 
 async def send_comment(
@@ -304,3 +318,37 @@ async def get_comments(
     api = API["comment"]["get"]
     params = {"pn": page_index, "type": type_.value, "oid": oid, "sort": order.value}
     return await Api(**api, credential=credential).update_params(**params).result
+
+
+async def get_comments_lazy(
+    oid: int,
+    type_: CommentResourceType,
+    pagination_str: str = "",
+    order: OrderType = OrderType.TIME,
+    credential: Union[Credential, None] = None,
+) -> dict:
+    """
+    新版获取资源评论列表。
+
+    Args:
+        oid        (int)                 : 资源 ID。
+
+        type_      (CommentsResourceType)        : 资源类枚举。
+
+        pagination_str (str, optional)       : 分页依据 Defaults to `{"offset":""}`.
+
+        order      (OrderType, optional) : 排序方式枚举. Defaults to OrderType.TIME.
+
+        credential (Credential, optional): 凭据。Defaults to None.
+
+    Returns:
+        dict: 调用 API 返回的结果
+    """
+    api = API["comment"]["reply_by_session_id"]
+    params = {
+        "oid": oid,
+        "type": type_.value,
+        "mode": order.value,
+        "pagination_str": '{"offset": "%s"}' % pagination_str.replace('"', r"\""),
+    }
+    return await Api(**api, credential=credential).update_params(**params).result
