@@ -15,7 +15,7 @@ from bilibili_api.utils.utils import get_api
 from bilibili_api.errors import ArgsException
 from bilibili_api.utils.picture import Picture
 from bilibili_api.utils.credential import Credential
-from bilibili_api.utils.network_httpx import HEADERS, request, Api
+from bilibili_api.utils.network import HEADERS, Api
 
 API = get_api("manga")
 
@@ -157,15 +157,22 @@ class Manga:
         """
         api = API["info"]["detail"]
         params = {"comic_id": self.__manga_id}
-        return await Api(
-            **api,
-            credential=self.credential,
-            no_csrf=(
-                False
-                if (self.credential.has_sessdata() and self.credential.has_bili_jct())
-                else True
-            ),
-        ).update_params(**params).result
+        return (
+            await Api(
+                **api,
+                credential=self.credential,
+                no_csrf=(
+                    False
+                    if (
+                        self.credential.has_sessdata()
+                        and self.credential.has_bili_jct()
+                    )
+                    else True
+                ),
+            )
+            .update_params(**params)
+            .result
+        )
 
     async def __get_info_cached(self) -> dict:
         """
@@ -245,15 +252,22 @@ class Manga:
             episode_id = await self.get_episode_id(episode_count)
         api = API["info"]["episode_images"]
         params = {"ep_id": episode_id}
-        return await Api(
-            **api,
-            credential=self.credential,
-            no_csrf=(
-                False
-                if (self.credential.has_sessdata() and self.credential.has_bili_jct())
-                else True
-            ),
-        ).update_params(**params).result
+        return (
+            await Api(
+                **api,
+                credential=self.credential,
+                no_csrf=(
+                    False
+                    if (
+                        self.credential.has_sessdata()
+                        and self.credential.has_bili_jct()
+                    )
+                    else True
+                ),
+            )
+            .update_params(**params)
+            .result
+        )
 
     async def get_images(
         self,
@@ -283,15 +297,22 @@ class Manga:
         async def get_real_image_url(url: str) -> str:
             token_api = API["info"]["image_token"]
             datas = {"urls": f'["{url}"]'}
-            token_data = await Api(
-            **token_api,
-            credential=self.credential,
-            no_csrf=(
-                False
-                if (self.credential.has_sessdata() and self.credential.has_bili_jct())
-                else True
-            ),
-        ).update_data(**datas).result
+            token_data = (
+                await Api(
+                    **token_api,
+                    credential=self.credential,
+                    no_csrf=(
+                        False
+                        if (
+                            self.credential.has_sessdata()
+                            and self.credential.has_bili_jct()
+                        )
+                        else True
+                    ),
+                )
+                .update_data(**datas)
+                .result
+            )
             return token_data[0]["url"] + "?token=" + token_data[0]["token"]
 
         for img in data["images"]:
@@ -329,15 +350,19 @@ async def manga_image_url_turn_to_Picture(
     async def get_real_image_url(url: str) -> str:
         token_api = API["info"]["image_token"]
         datas = {"urls": f'["{url}"]'}
-        token_data = await Api(
-            **token_api,
-            credential=credential,
-            no_csrf=(
-                False
-                if (credential.has_sessdata() and credential.has_bili_jct())
-                else True
-            ),
-        ).update_data(**datas).result
+        token_data = (
+            await Api(
+                **token_api,
+                credential=credential,
+                no_csrf=(
+                    False
+                    if (credential.has_sessdata() and credential.has_bili_jct())
+                    else True
+                ),
+            )
+            .update_data(**datas)
+            .result
+        )
         return f'{token_data[0]["url"]}?token={token_data[0]["token"]}'
 
     url = await get_real_image_url(url)
@@ -413,7 +438,13 @@ async def get_raw_manga_index(
         "page_num": pn,
         "page_size": ps,
     }
-    return await Api(**api, no_csrf=True).update_data(**data).update_params(**params).result
+    return (
+        await Api(**api, no_csrf=True)
+        .update_data(**data)
+        .update_params(**params)
+        .result
+    )
+
 
 async def get_manga_index(
     area: MangaIndexFilter.Area = MangaIndexFilter.Area.ALL,
@@ -470,7 +501,12 @@ async def get_manga_update(
     if isinstance(date, datetime.datetime):
         date = date.strftime("%Y-%m-%d")
     data = {"date": date, "page_num": pn, "page_size": ps}
-    manga_data = await Api(**api, no_csrf=True).update_data(**data).update_params(**params).result
+    manga_data = (
+        await Api(**api, no_csrf=True)
+        .update_data(**data)
+        .update_params(**params)
+        .result
+    )
     return [Manga(manga["comic_id"]) for manga in manga_data["list"]]
 
 
@@ -491,5 +527,10 @@ async def get_manga_home_recommend(
     api = API["info"]["home_recommend"]
     params = {"device": "pc", "platform": "web"}
     data = {"page_num": pn, "seed": seed}
-    manga_data = await Api(**api, no_csrf=True).update_data(**data).update_params(**params).result
+    manga_data = (
+        await Api(**api, no_csrf=True)
+        .update_data(**data)
+        .update_params(**params)
+        .result
+    )
     return [Manga(manga["comic_id"]) for manga in manga_data["list"]]
