@@ -5,16 +5,25 @@ bilibili_api.utils.initial_state
 """
 import re
 import json
-
 import httpx
+from enum import Enum
+from typing import Union
 
 from ..exceptions import *
 from .short import get_real_url
 from .credential import Credential
-from .network_httpx import get_session
+from .network import get_session
 
 
-async def get_initial_state(url: str, credential: Credential = Credential()) -> dict:
+class InitialDataType(Enum):
+    '''
+    识别返回类型
+    '''
+    INITIAL_STATE = "window.__INITIAL_STATE__"
+    NEXT_DATA = "__NEXT_DATA__"
+
+
+async def get_initial_state(url: str, credential: Credential = Credential()) -> Union[dict, InitialDataType]:
     '''
     异步获取初始化信息
 
@@ -38,15 +47,22 @@ async def get_initial_state(url: str, credential: Credential = Credential()) ->
         pattern = re.compile(r"window.__INITIAL_STATE__=(\{.*?\});")
         match = re.search(pattern, content)
         if match is None:
-            raise ApiException("未找到相关信息")
+            pattern = re.compile(pattern = r'<script id="__NEXT_DATA__" type="application/json">\s*(.*?)\s*</script>')
+            match = re.search(pattern, content)
+            content_type = InitialDataType.NEXT_DATA
+            if match is None:
+                raise ApiException("未找到相关信息")
+        else:
+            content_type = InitialDataType.INITIAL_STATE
         try:
             content = json.loads(match.group(1))
         except json.JSONDecodeError:
             raise ApiException("信息解析错误")
 
-        return content
+        return content, content_type
 
-def get_initial_state_sync(url: str, credential: Credential = Credential()) -> dict:
+
+def get_initial_state_sync(url: str, credential: Credential = Credential()) -> Union[dict, InitialDataType]:
     '''
     同步获取初始化信息
 
@@ -69,10 +85,16 @@ def get_initial_state_sync(url: str, credential: Credential = Credential()) -> d
         pattern = re.compile(r"window.__INITIAL_STATE__=(\{.*?\});")
         match = re.search(pattern, content)
         if match is None:
-            raise ApiException("未找到相关信息")
+            pattern = re.compile(pattern = r'<script id="__NEXT_DATA__" type="application/json">\s*(.*?)\s*</script>')
+            match = re.search(pattern, content)
+            content_type = InitialDataType.NEXT_DATA
+            if match is None:
+                raise ApiException("未找到相关信息")
+        else:
+            content_type = InitialDataType.INITIAL_STATE
         try:
             content = json.loads(match.group(1))
         except json.JSONDecodeError:
             raise ApiException("信息解析错误")
 
-        return content
\ No newline at end of file
+        return content, content_type
\ No newline at end of file
