@@ -9,7 +9,7 @@ import httpx
 
 from .. import settings
 from .credential import Credential
-from .network_httpx import get_session
+from .network import get_session
 
 
 async def get_real_url(short_url: str, credential: Optional[Credential] = None) -> str:
